변경사항
=============

## v1.0.0

+ pyufp 정식 버전 릴리즈.

#### v1.0.1

+ 설치 파일 수정
+ 기존에 터미널을 제어하던 부분에서 ANSIColors-balises을 사용하도록 수정
+ ufp.terminal.color 부분을 호환성 유지를 위한 항목으로 이동

#### v1.0.2

+ 설치 파일 오류 수정

#### v1.0.3

+ 설치 파일 오류 수정

#### v1.0.4

+ 설치 파일 오류 수정

#### v1.0.5

+ 설치 파일 오류 수정

#### v1.0.5b

+ 설치 파일 오류 수정

#### v1.0.5b1

+ 설치 파일 오류 수정

#### v1.0.5b2

+ 설치 파일 오류 수정
